@@ -3,7 +3,7 @@ from inspect import isclass
 import sqlalchemy as sa
 from .translatable import Translatable
 from .builders import (
-    TranslationModelBuilder, HybridPropertyBuilder
+    TranslationModelBuilder, HybridPropertyBuilder, ImproperlyConfigured
 )
 
 
@@ -49,7 +49,8 @@ class TranslationManager(object):
             'table_name': '%s_translation',
             'locale_column_name': 'locale',
             'default_locale': 'en',
-            'get_locale_fallback': False
+            'get_locale_fallback': False,
+            'exclude_hybrid_properties': []
         }
 
     def instrument_translatable_classes(self, mapper, cls):
@@ -59,16 +60,20 @@ class TranslationManager(object):
                 self.pending_classes.append(cls)
 
     def configure_translatable_classes(self):
-        for cls in self.pending_classes:
-            builder = TranslationModelBuilder(self, cls)
-            self.class_map[cls] = builder()
-            builder = HybridPropertyBuilder(self, cls)
-            builder()
+        try:
+            for cls in self.pending_classes:
+                builder = TranslationModelBuilder(self, cls)
+                self.class_map[cls] = builder()
+                builder = HybridPropertyBuilder(self, cls)
+                builder()
 
-        pending_classes_copy = copy(self.pending_classes)
-        self.pending_classes = []
-        for cls in leaf_classes(pending_classes_copy):
-            self.build_relationships(cls)
+            pending_classes_copy = copy(self.pending_classes)
+            self.pending_classes = []
+            for cls in leaf_classes(pending_classes_copy):
+                self.build_relationships(cls)
+        except ImproperlyConfigured:
+            self.pending_classes = []
+            raise
 
     def closest_generated_parent(self, model):
         for class_ in model.__bases__:
